@@ -1,8 +1,4 @@
-pub type BoxError = std::boxed::Box<
-    dyn std::error::Error // must implement Error to satisfy ?
-        + std::marker::Send // needed for threads
-        + std::marker::Sync, // needed for threads
->;
+pub type BoxError = std::boxed::Box<dyn std::error::Error>;
 
 #[derive(Debug)]
 pub struct Error {
